package com.ufo.gatling;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.util.List;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import com.ufo.gatling.entity.Emp;
import com.ufo.gatling.mapper.EmpMapper;

@SpringBootTest
class GatlingApplicationTests {
	@Autowired
	private EmpMapper mapper=null;

	@Test
	void test01_findById() {
		Emp emp=mapper.findById(6);
		assertEquals("Felix", emp.getName());
		assertEquals(20000, emp.getSalary());
	}
	
	@Test
	void test02_findAll() {
		List<Emp> empList=mapper.findAll();
		assertEquals(6, empList.size());
	}
	
	@Test
	void test03_updateById() {
		Emp emp=new Emp();
		emp.setId(1);
		emp.setName("Gates");
		emp.setSalary(123456);
		
		int changedCount=mapper.updateById(emp);
		assertEquals(1, changedCount);
		
		Emp found=mapper.findById(1);
		assertEquals("Gates", found.getName());
		assertEquals(123456, found.getSalary());
	}
	
	@Test
	void test04_deleteById() {
		Emp emp=new Emp();
		emp.setId(3);
		
		int changedCount=mapper.deleteById(emp);
		assertEquals(1, changedCount);
		
		emp=mapper.findById(3);
		assertEquals(null, emp);
	}
	
	@Test
	void test05_insert() {
		Emp emp=new Emp();
		emp.setId(7);
		emp.setName("Bear");
		emp.setSalary(300000);
		
		int changedCount=mapper.insert(emp);
		assertEquals(1, changedCount);
		
		Emp found=mapper.findById(7);
		assertEquals("Bear", found.getName());
		assertEquals(300000, found.getSalary());
	}
	
	@Test
	void test06_findHighLevelEmps() {
		List<Emp> empList=mapper.findHighLevelEmps();
		assertEquals(4, empList.size());
	}
}
